DIDP Papers
===========

* Ryo Kuroiwa and J. Christopher Beck. `Domain-Independent Dynamic Programming: Generic State Space Search for Combinatorial Optimization <https://ojs.aaai.org/index.php/ICAPS/article/view/27200/26973>`_. In Proceedings of the 33rd International Conference on Automated Planning and Scheduling (ICAPS). 2023.
    * This paper introduces the paradigm of DIDP, :class:`~didppy.CAASDy`, and DIDP models for :ref:`TSPTW <tutorial:TSPTW>`, the capacitated vehicle routing problem (CVRP), bin packing, the simple assembly line balancing problem (SALBP-1), :ref:`MOSP <advanced-tutorials/general-cost:MOSP>`, and graph-clear.
* Ryo Kuroiwa and J. Christopher Beck. `Solving Domain-Independent Dynamic Programming Problems with Anytime Heuristic Search <https://ojs.aaai.org/index.php/ICAPS/article/view/27201/26974>`_. In Proceedings of the 33rd International Conference on Automated Planning and Scheduling (ICAPS). 2023.
    * This paper introduces anytime solvers for DIDP including :class:`~didppy.CABS` and DIDP models for the multi-commodity pick-and-delivery traveling salesperson problem (m-PDTSP), the :ref:`talent scheduling problem <advanced-tutorials/forced-transitions:Talent Scheduling>`, and the single machine scheduling to minimize total weighted tardiness (:math:`1||\sum w_iT_i`).
* Ryo Kuroiwa and J. Christopher Beck. `Large Neighborhood Beam Search for Domain-Independent Dynamic Programming <https://tidel.mie.utoronto.ca/pubs/LNBS_CP23.pdf>`_. In Proceedings of the 29th International Conference on Principles and Practice of Constraint Programming (CP). 2023.
    * This paper introduces Large Neighborhood Beam Search (LNBS).

